#!/bin/sh
# ----------------------------------------------------------------------------
# /var/install/config.d/upmpdcli-update.sh - paramater update script
#
# Creation   :  2015-09-15 Tom Schulz, tom_strike(at)gmx(dot)de
# Last Update:  2015-09-27 Tom Schulz
#
# Copyright (c) 2015-09-15 Tom Schulz, tom_strike(at)gmx(dot)de
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ----------------------------------------------------------------------------

# include configlib for using printvar
. /var/install/include/configlib

# include eislib
. /var/install/include/eislib

# set packages name
packageName=upmpdcli

# ----------------------------------------------------------------------------
# Set the default values for configuration
# ----------------------------------------------------------------------------
START_UPMPDCLI='no'
UPMPDCLI_MPD_HOST='127.0.0.1'
UPMPDCLI_MPD_PORT='6600'
UPMPDCLI_MPD_QUEUE='yes'
UPMPDCLI_UPNP_NAME='UpMpd'
UPMPDCLI_UPNP_NIC='eth0'
UPMPDCLI_UPNP_PORT='49152'
UPMPDCLI_ENABLE_OPENHOME='no'
UPMPDCLI_LOG_LEVEL='0'
UPMPDCLI_LOG_INTERVAL='weekly'
UPMPDCLI_LOG_COUNT='7'

# ----------------------------------------------------------------------------
# Read old configuration and rename old variables
# ----------------------------------------------------------------------------
renameOldVariables()
{
    # read old values
    if [ -f /etc/config.d/${packageName} ]
    then
         /var/install/bin/backup-file --quiet ${packageName}
        . /etc/config.d/${packageName}
    fi
}

# ----------------------------------------------------------------------------
# Write config and default files
# ----------------------------------------------------------------------------
makeConfigFile()
{
    internal_conf_file=${1}
    {
    # ------------------------------------------------------------------------
    printgpl -conf ${packageName} "2015-09-27" "Tom Schulz"
    # ------------------------------------------------------------------------

    # ------------------------------------------------------------------------
    printgroup "Basic configuration"
    # ------------------------------------------------------------------------
    printvar "START_UPMPDCLI" "Start UpMpdCli? Use: yes or no"
    printvar "UPMPDCLI_MPD_HOST" "Host MPD runs on"
    printvar "UPMPDCLI_MPD_PORT" "Port for MPD"
    printvar "UPMPDCLI_MPD_QUEUE" "Enable caching of group communication network state"
    printvar "UPMPDCLI_UPNP_NAME" "Advertising name for the UPnP Media Renderer"
    printvar "UPMPDCLI_UPNP_NIC" "Network interface to use for UPnP"
    printvar "UPMPDCLI_UPNP_PORT" "Port number used for UPnP"
    printvar "UPMPDCLI_ENABLE_OPENHOME" "Decide if we offer the OpenHome services"

    # ------------------------------------------------------------------------
    printgroup "Advanced configuration"
    # ------------------------------------------------------------------------
    printvar "UPMPDCLI_LOG_LEVEL" "Set log level"
    printvar "UPMPDCLI_LOG_INTERVAL" "daily|weekly|monthly"
    printvar "UPMPDCLI_LOG_COUNT" "Number of logfiles to keep"

    # ------------------------------------------------------------------------
    printend
    # ------------------------------------------------------------------------

    } > ${internal_conf_file}
    # Set rights
    chmod 0600 ${internal_conf_file}
    chown root ${internal_conf_file}
}

# ----------------------------------------------------------------------------
# Create the check.d file
# ----------------------------------------------------------------------------
makeCheckFile()
{

# create file check.d

    printgpl -check ${packageName} '2015-09-27' 'Tom Schulz' >/etc/check.d/${packageName}
    cat >> /etc/check.d/${packageName} <<EOFG

# Variable                OPT_VARIABLE      VARIABLE_N          VALUE
START_UPMPDCLI            -                 -                   YESNO
UPMPDCLI_MPD_HOST         START_UPMPDCLI    -                   IPADDR
UPMPDCLI_MPD_PORT         START_UPMPDCLI    -                   PORT
UPMPDCLI_MPD_QUEUE        START_UPMPDCLI    -                   YESNO
UPMPDCLI_UPNP_NAME        START_UPMPDCLI    -                   NOBLANK
UPMPDCLI_UPNP_NIC         START_UPMPDCLI    -                   UPMPDCLI_UPNP_NIC
UPMPDCLI_UPNP_PORT        START_UPMPDCLI    -                   PORT
UPMPDCLI_ENABLE_OPENHOME  START_UPMPDCLI    -                   YESNO
UPMPDCLI_LOG_LEVEL        START_UPMPDCLI    -                   UPMPDCLI_LOG_LEVEL
UPMPDCLI_LOG_INTERVAL     START_UPMPDCLI    -                   LOG_INTERVAL
UPMPDCLI_LOG_COUNT        START_UPMPDCLI    -                   NUMERIC

EOFG

# Set rights for check.d file
chmod 0600 /etc/check.d/${packageName}
chown root /etc/check.d/${packageName}

printgpl --check_exp ${packageName} '2015-08-15' 'Tom Schulz' >/etc/check.d/${packageName}.exp
cat >> /etc/check.d/${packageName}.exp <<EOFG

UPMPDCLI_UPNP_NIC            = '(RE:ETH_BASE_DEV_NAME)|wlan0|wlan1|wlan2|wlan3'
                             : 'Network interface'

UPMPDCLI_LOG_LEVEL           = '[0-6]'
                             : 'only numeric values between 0 and 6 allowed'

EOFG

# Set rights for check.exp file
chmod 0600 /etc/check.d/${packageName}.exp
chown root /etc/check.d/${packageName}.exp

# printgpl --check_ext ${packageName} '2015-09-15' 'Tom Schulz' >/etc/check.d/${packageName}.ext
# cat >> /etc/check.d/${packageName}.ext <<EOFG
#
# EOFG

# Set rights for check.ext file
# chmod 0600 /etc/check.d/${packageName}.ext
# chown root /etc/check.d/${packageName}.ext
# create file check.ext - not used yet

}

# ----------------------------------------------------------------------------
# Main
# ----------------------------------------------------------------------------
# Write default config file

makeConfigFile /etc/default.d/${packageName}

# Update from old version
renameOldVariables

# Write new config file
makeConfigFile /etc/config.d/${packageName}

# Write check.d file
makeCheckFile

exit 0
# ----------------------------------------------------------------------------
# End
# ----------------------------------------------------------------------------
